==> audiochain-1.1.5-src.tgz: org/audiochain/ui/gui/mixer/EditAudioProjectDialog.java <==
/**
   AudioChain Copyright (C) 2012-2013 Florian Paul (www.audiochain.org)
   
   This program is free software; you can redistribute it and/or modify it under the terms of the 
   GNU General Public License as published by the Free Software Foundation; either version 3 of the 
   License, or (at your option) any later version.
   
   This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
   even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
   Public License for more details.
   
   You should have received a copy of the GNU General Public License along with this program; 
   if not, see <http://www.gnu.org/licenses/>. 
 */
package org.audiochain.ui.gui.mixer;

import static org.audiochain.ui.gui.Dialog.*;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.GroupLayout;
import javax.swing.GroupLayout.Alignment;
import javax.swing.JCheckBox;
import javax.swing.JLabel;
import javax.swing.JTextField;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;

import org.audiochain.model.AudioChannels;
import org.audiochain.model.AudioMixer;
import org.audiochain.model.AudioProject;
import org.audiochain.ui.gui.AudioChannelsCheckBox;
import org.audiochain.ui.gui.LightEmittingDiodeCheckBox;


public class EditAudioProjectDialog extends CreateNewAudioProjectDialog {
	private final Object audioFormatNotificationKey = new Object();
	private JLabel sampleRateLabel;
	private JTextField sampleRateField;
	private JLabel sampleSizeLabel;
	private JTextField sampleSizeField;
	private JLabel bigEndianLabel;
	private JCheckBox bigEndianCheckBox;
	private JLabel audioChannelsLabel;
	private AudioChannelsCheckBox audioChannelsCheckBox;

	public EditAudioProjectDialog(Object caller, AudioProject project) {
		super(caller);
		if (project == null) {
			throw new IllegalArgumentException("The Audio Project must no be null.");
		}
		this.audioProject = project;
		initValues();
		registerListeners();
		createLayout();
		showDialog();
	}

	@Override
	protected void init() {
		createMainComponents();
		createApplyButton("Apply Changes");
		createProjectNameComponents();
		createProjectPathComponents("Project Path:");
		createTemplatePathComponents();
		createSampleRateComponents();
		createSampleSizeComponents();
		createBigEndianComponents();
		createAudioChannelsComponents();
	}

	private void createAudioChannelsComponents() {
		audioChannelsLabel = new JLabel("Channels:");
		audioChannelsCheckBox = new AudioChannelsCheckBox();
	}

	private void createBigEndianComponents() {
		bigEndianLabel = new JLabel("Big Endian:");
		bigEndianCheckBox = new LightEmittingDiodeCheckBox();
	}

	private void createSampleSizeComponents() {
		sampleSizeLabel = new JLabel("Sample Size In Bits:");
		sampleSizeField = new JTextField(5);
	}

	private void createSampleRateComponents() {
		sampleRateLabel = new JLabel("Sample Rate:");
		sampleRateField = new JTextField(5);
	}

	private void initValues() {
		this.projectNameField.setText(audioProject.getName());
		this.projectPathField.setText(audioProject.getProjectPath());
		this.templatePathField.setText(audioProject.getTemplateFileName());
		this.sampleRateField.setText(String.valueOf(audioProject.getSampleRate()));
		this.sampleSizeField.setText(String.valueOf(audioProject.getSampleSizeInBits()));
		this.bigEndianCheckBox.setSelected(audioProject.isBigEndian());
		this.audioChannelsCheckBox.setAudioChannels(audioProject.getChannels());
	}

	private void registerListeners() {
		sampleSizeField.getDocument().addDocumentListener(new DocumentListener() {
			@Override
			public void insertUpdate(DocumentEvent e) {
				evaluateSampleSize();
			}

			@Override
			public void removeUpdate(DocumentEvent e) {
				evaluateSampleSize();
			}

			@Override
			public void changedUpdate(DocumentEvent e) {
				evaluateSampleSize();
			}
		});
		sampleRateField.getDocument().addDocumentListener(new DocumentListener() {
			@Override
			public void insertUpdate(DocumentEvent e) {
				evaluateSampleRate();
			}

			@Override
			public void removeUpdate(DocumentEvent e) {
				evaluateSampleRate();
			}

			@Override
			public void changedUpdate(DocumentEvent e) {
				evaluateSampleRate();
			}
		});
		bigEndianCheckBox.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				checkAudioFormat();
			}
		});
		audioChannelsCheckBox.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				checkAudioFormat();
			}
		});
	}

	private void showDialog() {
		if (isButtonPressed(caller, "Audio Project Settings", mainPanel, applyButton)) {
			String projectPath = projectPathField.getText();
			if (projectPath == null || projectPath.trim().isEmpty()) {
				throw new IllegalStateException("The audio project path must not be null.");
			}
			audioProject.setProjectPath(projectPath);

			String projectName = projectNameField.getText();
			if (projectName == null || projectName.trim().isEmpty()) {
				audioProject.setName(null);
			} else {
				audioProject.setName(projectName);
			}
			
			String templateFileName = templatePathField.getText();
			if (templateFileName == null || templateFileName.trim().isEmpty()) {
				audioProject.setTemplateFileName(null);
			} else {
				audioProject.setTemplateFileName(templateFileName);
			}

			audioProject.setSampleRate(Integer.parseInt(sampleRateField.getText()));
			audioProject.setSampleSizeInBits(Integer.parseInt(sampleSizeField.getText()));
			audioProject.setChannels(audioChannelsCheckBox.getAudioChannels());
			audioProject.setBigEndian(bigEndianCheckBox.isSelected());
		}
	}

	private void checkAudioFormat() {
		// assert that the format is supported.
		int sampleRate;
		try {
			sampleRate = Integer.parseInt(sampleRateField.getText());
		} catch (NumberFormatException e) {
			return;
		}
		int sampleSizeInBits;
		try {
			sampleSizeInBits = Integer.parseInt(sampleSizeField.getText());
		} catch (NumberFormatException e) {
			return;
		}
		AudioChannels channels = audioChannelsCheckBox.getAudioChannels();
		boolean bigEndian = bigEndianCheckBox.isSelected();
		String message = null;
		try {
			AudioMixer.getInstance().verifyAudioFormat(sampleRate, sampleSizeInBits, channels, bigEndian);
		} catch (Exception e) {
			message = e.getMessage();
		}
		putNotification(audioFormatNotificationKey, message);
	}

	private void createLayout() {
		GroupLayout layout = new GroupLayout(mainPanel);
		mainPanel.setLayout(layout);
		layout.setAutoCreateContainerGaps(true);
		layout.setAutoCreateGaps(true);
		
		layout.setHorizontalGroup(layout.createParallelGroup()
			.addComponent(notificationLabel)
			.addGroup(layout.createSequentialGroup()
				.addGroup(layout.createParallelGroup()
					.addComponent(projectNameLabel)
					.addComponent(projectPathLabel)
					.addComponent(templatePathLabel)
				)
				.addGroup(layout.createParallelGroup()
					.addComponent(projectNameField)
					.addGroup(layout.createSequentialGroup()
						.addComponent(projectPathField)
						.addComponent(searchProjectPathButton)
					)
					.addGroup(layout.createSequentialGroup()
						.addComponent(templatePathField)
						.addComponent(searchTemplatePathButton)
					)
				)
			)
			.addGroup(layout.createSequentialGroup()
				.addGroup(layout.createParallelGroup()
					.addComponent(sampleRateLabel)
					.addComponent(sampleSizeLabel)
				)
				.addGroup(layout.createParallelGroup()
					.addComponent(sampleRateField)
					.addComponent(sampleSizeField)
				)
				.addGroup(layout.createParallelGroup()
					.addComponent(audioChannelsLabel)
					.addComponent(bigEndianLabel)
				)
				.addGroup(layout.createParallelGroup()
					.addComponent(audioChannelsCheckBox)
					.addComponent(bigEndianCheckBox)
				)
			)
		);
		
		layout.setVerticalGroup(layout.createSequentialGroup()
			.addComponent(notificationLabel)
			.addGroup(layout.createParallelGroup(Alignment.BASELINE)
				.addComponent(projectNameLabel)
				.addComponent(projectNameField)
			)
			.addGroup(layout.createParallelGroup(Alignment.BASELINE)
				.addComponent(projectPathLabel)
				.addComponent(projectPathField)
				.addComponent(searchProjectPathButton)
			)
			.addGroup(layout.createParallelGroup(Alignment.BASELINE)
					.addComponent(templatePathLabel)
					.addComponent(templatePathField)
				.addComponent(projectPathField)
				.addComponent(searchTemplatePathButton)
			)
			.addGroup(layout.createParallelGroup(Alignment.BASELINE)
				.addComponent(sampleRateLabel)
				.addComponent(sampleRateField)
				.addComponent(audioChannelsLabel)
				.addComponent(audioChannelsCheckBox)
			)
			.addGroup(layout.createParallelGroup(Alignment.BASELINE)
				.addComponent(sampleSizeLabel)
				.addComponent(sampleSizeField)
				.addComponent(bigEndianLabel)
				.addComponent(bigEndianCheckBox)
			)
			// add additional gap to the dialog buttons, because the notification label causes an additional distance to the dialog title on the top
			.addGap(20)
		);
	}

	private void evaluateSampleRate() {
		String sampleRateString = sampleRateField.getText();
		String message = null;
		if (sampleRateString == null || sampleRateString.trim().isEmpty()) {
			message = "Sample Rate has no value.";
		} else {
			try {
				Integer.parseInt(sampleRateString);
				checkAudioFormat();
			} catch (NumberFormatException e) {
				message = "Sample Rate must be numeric." + e.getMessage();
			}
		}
		putNotification(sampleRateField, message);
	}

	private void evaluateSampleSize() {
		String sampleSizeString = sampleSizeField.getText();
		String message = null;
		if (sampleSizeString == null || sampleSizeString.isEmpty()) {
			message = "Sample Size has no value.";
		} else {
			try {
				Integer.parseInt(sampleSizeString);
				checkAudioFormat();
			} catch (NumberFormatException e) {
				message = "Sample Size must be numeric." + e.getMessage();
			}
		}
		putNotification(sampleSizeField, message);
	}
}

==> audiochain-1.1.6-src.tgz: org/audiochain/ui/gui/mixer/EditAudioProjectDialog.java <==
/**
   AudioChain Copyright (C) 2012-2013 Florian Paul (www.audiochain.org)
   
   This program is free software; you can redistribute it and/or modify it under the terms of the 
   GNU General Public License as published by the Free Software Foundation; either version 3 of the 
   License, or (at your option) any later version.
   
   This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
   even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
   Public License for more details.
   
   You should have received a copy of the GNU General Public License along with this program; 
   if not, see <http://www.gnu.org/licenses/>. 
 */
package org.audiochain.ui.gui.mixer;

import static org.audiochain.ui.gui.Dialog.isButtonPressed;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.GroupLayout;
import javax.swing.GroupLayout.Alignment;
import javax.swing.JCheckBox;
import javax.swing.JLabel;
import javax.swing.JTextField;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;

import org.audiochain.model.AudioChannels;
import org.audiochain.model.AudioMixer;
import org.audiochain.model.AudioProject;
import org.audiochain.ui.gui.AudioChannelsCheckBox;
import org.audiochain.ui.gui.LightEmittingDiodeCheckBox;


public class EditAudioProjectDialog extends CreateNewAudioProjectDialog {
	private final Object audioFormatNotificationKey = new Object();
	private JLabel sampleRateLabel;
	private JTextField sampleRateField;
	private JLabel sampleSizeLabel;
	private JTextField sampleSizeField;
	private JLabel bigEndianLabel;
	private JCheckBox bigEndianCheckBox;
	private JLabel audioChannelsLabel;
	private AudioChannelsCheckBox audioChannelsCheckBox;

	public EditAudioProjectDialog(Object caller, AudioProject project) {
		super(caller);
		if (project == null) {
			throw new IllegalArgumentException("The Audio Project must no be null.");
		}
		this.audioProject = project;
		initValues();
		registerListeners();
		createLayout();
		showDialog();
	}

	@Override
	protected void init() {
		createMainComponents();
		createApplyButton("Apply Changes");
		createProjectNameComponents();
		createProjectPathComponents("Project Path:");
		createTemplatePathComponents();
		createSampleRateComponents();
		createSampleSizeComponents();
		createBigEndianComponents();
		createAudioChannelsComponents();
	}

	private void createAudioChannelsComponents() {
		audioChannelsLabel = new JLabel("Channels:");
		audioChannelsCheckBox = new AudioChannelsCheckBox();
	}

	private void createBigEndianComponents() {
		bigEndianLabel = new JLabel("Big Endian:");
		bigEndianCheckBox = new LightEmittingDiodeCheckBox();
	}

	private void createSampleSizeComponents() {
		sampleSizeLabel = new JLabel("Sample Size In Bits:");
		sampleSizeField = new JTextField(5);
	}

	private void createSampleRateComponents() {
		sampleRateLabel = new JLabel("Sample Rate:");
		sampleRateField = new JTextField(5);
	}

	private void initValues() {
		this.projectNameField.setText(audioProject.getName());
		this.projectPathField.setText(audioProject.getProjectPath());
		this.templatePathField.setText(audioProject.getTemplateFileName());
		this.sampleRateField.setText(String.valueOf(audioProject.getSampleRate()));
		this.sampleSizeField.setText(String.valueOf(audioProject.getSampleSizeInBits()));
		this.bigEndianCheckBox.setSelected(audioProject.isBigEndian());
		this.audioChannelsCheckBox.setAudioChannels(audioProject.getChannels());
	}

	private void registerListeners() {
		sampleSizeField.getDocument().addDocumentListener(new DocumentListener() {
			@Override
			public void insertUpdate(DocumentEvent e) {
				evaluateSampleSize();
			}

			@Override
			public void removeUpdate(DocumentEvent e) {
				evaluateSampleSize();
			}

			@Override
			public void changedUpdate(DocumentEvent e) {
				evaluateSampleSize();
			}
		});
		sampleRateField.getDocument().addDocumentListener(new DocumentListener() {
			@Override
			public void insertUpdate(DocumentEvent e) {
				evaluateSampleRate();
			}

			@Override
			public void removeUpdate(DocumentEvent e) {
				evaluateSampleRate();
			}

			@Override
			public void changedUpdate(DocumentEvent e) {
				evaluateSampleRate();
			}
		});
		bigEndianCheckBox.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				checkAudioFormat();
			}
		});
		audioChannelsCheckBox.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				checkAudioFormat();
			}
		});
	}

	private void showDialog() {
		if (isButtonPressed(caller, "Audio Project Settings", mainPanel, applyButton)) {
			String projectPath = projectPathField.getText();
			if (projectPath == null || projectPath.trim().isEmpty()) {
				throw new IllegalStateException("The audio project path must not be null.");
			}
			audioProject.setProjectPath(projectPath);

			String projectName = projectNameField.getText();
			if (projectName == null || projectName.trim().isEmpty()) {
				audioProject.setName(null);
			} else {
				audioProject.setName(projectName);
			}
			
			String templateFileName = templatePathField.getText();
			if (templateFileName == null || templateFileName.trim().isEmpty()) {
				audioProject.setTemplateFileName(null);
			} else {
				audioProject.setTemplateFileName(templateFileName);
			}

			audioProject.setSampleRate(Integer.parseInt(sampleRateField.getText()));
			audioProject.setSampleSizeInBits(Integer.parseInt(sampleSizeField.getText()));
			audioProject.setChannels(audioChannelsCheckBox.getAudioChannels());
			audioProject.setBigEndian(bigEndianCheckBox.isSelected());
		}
	}

	private void checkAudioFormat() {
		// assert that the format is supported.
		int sampleRate;
		try {
			sampleRate = Integer.parseInt(sampleRateField.getText());
		} catch (NumberFormatException e) {
			return;
		}
		int sampleSizeInBits;
		try {
			sampleSizeInBits = Integer.parseInt(sampleSizeField.getText());
		} catch (NumberFormatException e) {
			return;
		}
		AudioChannels channels = audioChannelsCheckBox.getAudioChannels();
		boolean bigEndian = bigEndianCheckBox.isSelected();
		String message = null;
		try {
			AudioMixer.getInstance().verifyAudioFormat(sampleRate, sampleSizeInBits, channels, bigEndian);
		} catch (Exception e) {
			message = e.getMessage();
		}
		putNotification(audioFormatNotificationKey, message);
	}

	private void createLayout() {
		GroupLayout layout = new GroupLayout(mainPanel);
		mainPanel.setLayout(layout);
		layout.setAutoCreateContainerGaps(true);
		layout.setAutoCreateGaps(true);
		
		layout.setHorizontalGroup(layout.createParallelGroup()
			.addComponent(notificationLabel)
			.addGroup(layout.createSequentialGroup()
				.addGroup(layout.createParallelGroup()
					.addComponent(projectNameLabel)
					.addComponent(projectPathLabel)
					.addComponent(templatePathLabel)
				)
				.addGroup(layout.createParallelGroup()
					.addComponent(projectNameField)
					.addGroup(layout.createSequentialGroup()
						.addComponent(projectPathField)
						.addComponent(searchProjectPathButton)
					)
					.addGroup(layout.createSequentialGroup()
						.addComponent(templatePathField)
						.addComponent(searchTemplatePathButton)
					)
				)
			)
			.addGroup(layout.createSequentialGroup()
				.addGroup(layout.createParallelGroup()
					.addComponent(sampleRateLabel)
					.addComponent(sampleSizeLabel)
				)
				.addGroup(layout.createParallelGroup()
					.addComponent(sampleRateField)
					.addComponent(sampleSizeField)
				)
				.addGroup(layout.createParallelGroup()
					.addComponent(audioChannelsLabel)
					.addComponent(bigEndianLabel)
				)
				.addGroup(layout.createParallelGroup()
					.addComponent(audioChannelsCheckBox)
					.addComponent(bigEndianCheckBox)
				)
			)
		);
		
		layout.setVerticalGroup(layout.createSequentialGroup()
			.addComponent(notificationLabel)
			.addGroup(layout.createParallelGroup(Alignment.BASELINE)
				.addComponent(projectNameLabel)
				.addComponent(projectNameField)
			)
			.addGroup(layout.createParallelGroup(Alignment.BASELINE)
				.addComponent(projectPathLabel)
				.addComponent(projectPathField)
				.addComponent(searchProjectPathButton)
			)
			.addGroup(layout.createParallelGroup(Alignment.BASELINE)
					.addComponent(templatePathLabel)
					.addComponent(templatePathField)
				.addComponent(projectPathField)
				.addComponent(searchTemplatePathButton)
			)
			.addGroup(layout.createParallelGroup(Alignment.BASELINE)
				.addComponent(sampleRateLabel)
				.addComponent(sampleRateField)
				.addComponent(audioChannelsLabel)
				.addComponent(audioChannelsCheckBox)
			)
			.addGroup(layout.createParallelGroup(Alignment.BASELINE)
				.addComponent(sampleSizeLabel)
				.addComponent(sampleSizeField)
				.addComponent(bigEndianLabel)
				.addComponent(bigEndianCheckBox)
			)
			// add additional gap to the dialog buttons, because the notification label causes an additional distance to the dialog title on the top
			.addGap(20)
		);
	}

	private void evaluateSampleRate() {
		String sampleRateString = sampleRateField.getText();
		String message = null;
		if (sampleRateString == null || sampleRateString.trim().isEmpty()) {
			message = "Sample Rate has no value.";
		} else {
			try {
				Integer.parseInt(sampleRateString);
				checkAudioFormat();
			} catch (NumberFormatException e) {
				message = "Sample Rate must be numeric." + e.getMessage();
			}
		}
		putNotification(sampleRateField, message);
	}

	private void evaluateSampleSize() {
		String sampleSizeString = sampleSizeField.getText();
		String message = null;
		if (sampleSizeString == null || sampleSizeString.isEmpty()) {
			message = "Sample Size has no value.";
		} else {
			try {
				Integer.parseInt(sampleSizeString);
				checkAudioFormat();
			} catch (NumberFormatException e) {
				message = "Sample Size must be numeric." + e.getMessage();
			}
		}
		putNotification(sampleSizeField, message);
	}
}
